Address class

Annotations

Constructors

Address({required Coordinates coordinates, String? addressLine, String? countryName, String? countryCode, String? featureName, String? postalCode, String? adminArea, String? subAdminArea, String? locality, String? subLocality, String? thoroughfare, String? subThoroughfare})
Address.fromMap(Map map)
Creates an address from a map containing its properties.

Properties

addressLine → String?
The formatted address with all lines.
final
adminArea → String?
The administrative area name of the address
final
coordinates → Coordinates
The geographic coordinates.
final
countryCode → String?
The country code of the address.
final
countryName → String?
The localized country name of the address.
final
featureName → String?
The feature name of the address.
final
hashCode → int
The hash code for this object.
no setterinherited
locality → String?
The locality of the address
final
postalCode → String?
The postal code.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subAdminArea → String?
The sub-administrative area name of the address
final
subLocality → String?
The sub-locality of the address
final
subThoroughfare → String?
The sub-thoroughfare name of the address
final
thoroughfare → String?
The thoroughfare name of the address
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map
Creates a map from the address properties.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited